==> django_graphene_crud_generator-1.7.8-py3-none-any.whl: django_graphene_crud_generator/generator/LambdaGraphQLQueryGenerator.py <==
from typing import Dict, List, Callable, Union, Tuple

import stringcase
from django_koldar_utils.graphql_toolsbox.graphql_types import TGrapheneArgument, TGrapheneWholeQueryReturnType

from django_graphene_crud_generator.generator.AbstractGraphQLMutationGenerator import AbstractGraphQLMutationGenerator
from django_graphene_crud_generator.generator.AbstractGraphQLQueryGenerator import AbstractGraphQLQueryGenerator
from django_graphene_crud_generator.generator.contexts import GraphQLBuildtimeContext, GraphQLRuntimeContext


class LambdaGraphQLQueryGenerator(AbstractGraphQLQueryGenerator):
    """
    A mutation generator that uses fields passed during initialization in order to generate the mutation class.
    Useful if you don't need to customize the behavior in any way
    """

    def _get_query_output_name(self, build_context: GraphQLBuildtimeContext) -> str:
        return self.output_name

    def _get_return_value_temp_type_name(self, builld_context: GraphQLBuildtimeContext) -> str:
        return f"{stringcase.pascalcase(self.output_name)}OutcomeType"

    def __init__(self, class_name: str,
        description: Union[str, List[str]],
        arguments: Dict[str, TGrapheneArgument],
        output_name: str,
        return_value: TGrapheneWholeQueryReturnType,
        callable: Callable[[any, any, List[any], Dict[str, any]], any]):

        super().__init__()
        self.class_name = class_name
        self.output_name = output_name
        self.description = description
        self.arguments = arguments
        self.return_value = return_value
        self.callable = callable

    def _generate_action_class_name(self, build_context: GraphQLBuildtimeContext) -> str:
        return self.class_name

    def _generate_action_description(self, build_context: GraphQLBuildtimeContext) -> List[str]:
        if isinstance(self.description, str):
            return [self.description]
        return self.description

    def _generate_action_arguments(self, build_context: GraphQLBuildtimeContext) -> Tuple[str, Dict[str, TGrapheneArgument]]:
        return "set", self.arguments

    def _generate_action_return_type(self, build_context: GraphQLBuildtimeContext) -> Tuple[str, TGrapheneWholeQueryReturnType]:
        return "set", self.return_value

    def graphql_body_function(self, runtime_context: GraphQLRuntimeContext, *args,
                              **kwargs) -> TGrapheneWholeQueryReturnType:
        return self.callable(runtime_context.root, runtime_context.info, *runtime_context.args, **runtime_context.kwargs)

==> django_graphene_crud_generator-1.7.9-py3-none-any.whl: django_graphene_crud_generator/generator/LambdaGraphQLQueryGenerator.py <==
from typing import Dict, List, Callable, Union, Tuple

import stringcase
from django_koldar_utils.graphql_toolsbox.graphql_types import TGrapheneArgument, TGrapheneWholeQueryReturnType

from django_graphene_crud_generator.generator.AbstractGraphQLMutationGenerator import AbstractGraphQLMutationGenerator
from django_graphene_crud_generator.generator.AbstractGraphQLQueryGenerator import AbstractGraphQLQueryGenerator
from django_graphene_crud_generator.generator.contexts import GraphQLBuildtimeContext, GraphQLRuntimeContext


class LambdaGraphQLQueryGenerator(AbstractGraphQLQueryGenerator):
    """
    A mutation generator that uses fields passed during initialization in order to generate the mutation class.
    Useful if you don't need to customize the behavior in any way
    """

    def _get_query_output_name(self, build_context: GraphQLBuildtimeContext) -> str:
        return self.output_name

    def _get_return_value_temp_type_name(self, builld_context: GraphQLBuildtimeContext) -> str:
        return f"{stringcase.pascalcase(self.output_name)}OutcomeType"

    def __init__(self, class_name: str,
        description: Union[str, List[str]],
        arguments: Dict[str, TGrapheneArgument],
        output_name: str,
        return_value: TGrapheneWholeQueryReturnType,
        callable: Callable[[any, any, List[any], Dict[str, any]], any]):

        super().__init__()
        self.class_name = class_name
        self.output_name = output_name
        self.description = description
        self.arguments = arguments
        self.return_value = return_value
        self.callable = callable

    def _generate_action_class_name(self, build_context: GraphQLBuildtimeContext) -> str:
        return self.class_name

    def _generate_action_description(self, build_context: GraphQLBuildtimeContext) -> List[str]:
        if isinstance(self.description, str):
            return [self.description]
        return self.description

    def _generate_action_arguments(self, build_context: GraphQLBuildtimeContext) -> Tuple[str, Dict[str, TGrapheneArgument]]:
        return "set", self.arguments

    def _generate_action_return_type(self, build_context: GraphQLBuildtimeContext) -> Tuple[str, TGrapheneWholeQueryReturnType]:
        if not isinstance(self.return_value, dict):
            result = {self._get_query_output_name(build_context): self.return_value}
        else:
            result = self.return_value
        return "update", result

    def graphql_body_function(self, runtime_context: GraphQLRuntimeContext, *args,
                              **kwargs) -> TGrapheneWholeQueryReturnType:
        return self.callable(runtime_context.root, runtime_context.info, *runtime_context.args, **runtime_context.kwargs)
